==> philib-0.9.1-sources.jar: ch/bind/philib/util/ArrayIterator.java <==
/*
 * Copyright (c) 2012 Philipp Meinen <philipp@bind.ch>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software
 * is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
 * THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package ch.bind.philib.util;

import java.util.Iterator;
import java.util.NoSuchElementException;

/**
 * An {@code Iterator} over an array.
 * 
 * @author Philipp Meinen
 */
public final class ArrayIterator<E> implements Iterator<E> {

	private final E[] data;

	private int nextIdx;

	/**
	 * Creates an array iterator which will iterate over the provided array.
	 * 
	 * @param data
	 *            the data to iterate over, may be null or empty.
	 */
	public ArrayIterator(E[] data) {
		this.data = data;
	}

	@Override
	public boolean hasNext() {
		return data != null && nextIdx < data.length;
	}

	@Override
	public E next() {
		if (!hasNext()) {
			throw new NoSuchElementException();
		}
		return data[nextIdx++];
	}

	@Override
	public void remove() {
		throw new UnsupportedOperationException();
	}
}

==> philib-0.12.0-sources.jar: ch/bind/philib/util/ArrayIterator.java <==
/*
 * Copyright (c) 2012 Philipp Meinen <philipp@bind.ch>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software
 * is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
 * THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package ch.bind.philib.util;

import java.util.Iterator;
import java.util.NoSuchElementException;

/**
 * An {@code Iterator} over an array.
 *
 * @author Philipp Meinen
 */
public final class ArrayIterator<E> implements Iterator<E> {

	private final E[] data;

	private int nextIdx;

	/**
	 * Creates an array iterator which will iterate over the provided array.
	 *
	 * @param data the data to iterate over, may be null or empty.
	 */
	public ArrayIterator(E[] data) {
		this.data = data;
	}

	@Override
	public boolean hasNext() {
		return data != null && nextIdx < data.length;
	}

	@Override
	public E next() {
		if (!hasNext()) {
			throw new NoSuchElementException();
		}
		return data[nextIdx++];
	}

	@Override
	public void remove() {
		throw new UnsupportedOperationException();
	}
}
